package org.acme.microprofile.graphql;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class FilmResourceIT extends FilmResourceTest {

}
